@@ -82,8 +82,12 @@ class Client:
 
     def stop(self) -> None:
         self.stopped = True
+        self._close_socket()
+
+    def _close_socket(self) -> None:
         if self.socket is not None:
             self.socket.close()
+        self.socket = None
 
     async def consume(self) -> None:
         while not self.stopped:
@@ -160,7 +164,15 @@ class Client:
 
     def _send_bytes(self, payload: bytes) -> None:
         self._init_socket_if_not_done()
-        self.socket.sendto(payload, (MDNS_ADDR, MDNS_PORT))
+        try:
+            self.socket.sendto(payload, (MDNS_ADDR, MDNS_PORT))
+        except OSError:
+            # This sendto function sometimes returns an OSError with EBADF
+            # as a payload. To avoid a failure here, reiinitialize the socket
+            # and try again once.
+            self._close_socket()
+            self._init_socket()
+            self.socket.sendto(payload, (MDNS_ADDR, MDNS_PORT))
 
     def _init_socket_if_not_done(self) -> None:
         if self.socket is None:
